[SCM] Samba Shared Repository - branch master updated

Jeremy Allison jra at samba.org
Tue Jul 20 12:15:49 MDT 2010


The branch, master has been updated
       via  7d17bfc... Rename spnego_gen_negTokenTarg() -> spnego_gen_krb5_negTokenInit() as this correctly describes what this function does.
      from  8a882b6... Remove gen_negTokenTarg(), as it's not actually creating a TokenTarg frame, but a TokenInit one. Move to using spnego_gen_negTokenInit() instead.

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -----------------------------------------------------------------
commit 7d17bfcf51880c84a2f2173c941f2955d045f5c5
Author: Jeremy Allison <jra at samba.org>
Date:   Tue Jul 20 11:14:49 2010 -0700

    Rename spnego_gen_negTokenTarg() -> spnego_gen_krb5_negTokenInit()
    as this correctly describes what this function does.
    
    Jeremy.

-----------------------------------------------------------------------

Summary of changes:
 source3/include/proto.h     |    2 +-
 source3/libads/sasl.c       |    2 +-
 source3/libsmb/cliconnect.c |    6 +++---
 source3/libsmb/clispnego.c  |    6 +++---
 4 files changed, 8 insertions(+), 8 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source3/include/proto.h b/source3/include/proto.h
index 4d877fb..d154d34 100644
--- a/source3/include/proto.h
+++ b/source3/include/proto.h
@@ -2806,7 +2806,7 @@ bool spnego_parse_negTokenInit(DATA_BLOB blob,
 DATA_BLOB gen_negTokenTarg(const char *OIDs[], DATA_BLOB blob);
 DATA_BLOB spnego_gen_krb5_wrap(const DATA_BLOB ticket, const uint8 tok_id[2]);
 bool spnego_parse_krb5_wrap(DATA_BLOB blob, DATA_BLOB *ticket, uint8 tok_id[2]);
-int spnego_gen_negTokenTarg(const char *principal, int time_offset, 
+int spnego_gen_krb5_negTokenInit(const char *principal, int time_offset, 
 			    DATA_BLOB *targ, 
 			    DATA_BLOB *session_key_krb5, uint32 extra_ap_opts,
 			    time_t *expire_time);
diff --git a/source3/libads/sasl.c b/source3/libads/sasl.c
index 277231b..5cd5231 100644
--- a/source3/libads/sasl.c
+++ b/source3/libads/sasl.c
@@ -705,7 +705,7 @@ static ADS_STATUS ads_sasl_spnego_rawkrb5_bind(ADS_STRUCT *ads, const char *prin
 		return ADS_ERROR_NT(NT_STATUS_NOT_SUPPORTED);
 	}
 
-	rc = spnego_gen_negTokenTarg(principal, ads->auth.time_offset, &blob, &session_key, 0,
+	rc = spnego_gen_krb5_negTokenInit(principal, ads->auth.time_offset, &blob, &session_key, 0,
 				     &ads->auth.tgs_expire);
 
 	if (rc) {
diff --git a/source3/libsmb/clispnego.c b/source3/libsmb/clispnego.c
index 99d5b88..cd09a38 100644
--- a/source3/libsmb/clispnego.c
+++ b/source3/libsmb/clispnego.c
@@ -287,10 +287,10 @@ bool spnego_parse_krb5_wrap(DATA_BLOB blob, DATA_BLOB *ticket, uint8 tok_id[2])
 
 
 /* 
-   generate a SPNEGO negTokenTarg packet, ready for a EXTENDED_SECURITY
-   kerberos session setup 
+   generate a SPNEGO krb5 negTokenInit packet, ready for a EXTENDED_SECURITY
+   kerberos session setup
 */
-int spnego_gen_negTokenTarg(const char *principal, int time_offset, 
+int spnego_gen_krb5_negTokenInit(const char *principal, int time_offset, 
 			    DATA_BLOB *targ, 
 			    DATA_BLOB *session_key_krb5, uint32 extra_ap_opts,
 			    time_t *expire_time)


diff --git a/source3/libsmb/cliconnect.c b/source3/libsmb/cliconnect.c
index a8e359d..dc3f236 100644
--- a/source3/libsmb/cliconnect.c
+++ b/source3/libsmb/cliconnect.c
@@ -854,14 +854,14 @@ static struct tevent_req *cli_session_setup_kerberos_send(
 	cli_temp_set_signing(cli);
 
 	/*
 	 * Ok, this is cheated: spnego_gen_negTokenTarg can block if
 	 * we have to acquire a ticket. To be fixed later :-)
 	 */
-	rc = spnego_gen_negTokenTarg(principal, 0, &state->negTokenTarg,
+	rc = spnego_gen_krb5_negTokenInit(principal, 0, &state->negTokenTarg,
 				     &state->session_key_krb5, 0, NULL);
 	if (rc) {
 		DEBUG(1, ("cli_session_setup_kerberos: "
-			  "spnego_gen_negTokenTarg failed: %s\n",
+			  "spnego_gen_krb5_negTokenInit failed: %s\n",
 			  error_message(rc)));
 		state->ads_status = ADS_ERROR_KRB5(rc);
 		tevent_req_nterror(req, NT_STATUS_UNSUCCESSFUL);
@@ -854,14 +854,14 @@ static struct tevent_req *cli_session_setup_kerberos_send(
 
 	/*
-	 * Ok, this is cheated: spnego_gen_negTokenTarg can block if
+	 * Ok, this is cheating: spnego_gen_krb5_negTokenInit can block if
 	 * we have to acquire a ticket. To be fixed later :-)
 	 */
-- 
Samba Shared Repository


More information about the samba-cvs mailing list